Index: src/compiler/js-call-reducer.h |
diff --git a/src/compiler/js-call-reducer.h b/src/compiler/js-call-reducer.h |
index e31d9d79fdbea9e882f3ce2bc87f399643e495b4..f42c5fec0d401f782f8f478ec790b65a92a923a6 100644 |
--- a/src/compiler/js-call-reducer.h |
+++ b/src/compiler/js-call-reducer.h |
@@ -23,7 +23,7 @@ class JSGraph; |
class JSOperatorBuilder; |
class SimplifiedOperatorBuilder; |
// Performs strength reduction on {JSCallConstruct} and {JSCallFunction} nodes, |
// which might allow inlining or other optimizations to be performed afterwards. |
class JSCallReducer final : public AdvancedReducer { |
public: |
@@ -55,8 +55,8 @@ class JSCallReducer final : public AdvancedReducer { |
Reduction ReduceFunctionPrototypeCall(Node* node); |
Reduction ReduceFunctionPrototypeHasInstance(Node* node); |
Reduction ReduceObjectPrototypeGetProto(Node* node); |
- Reduction ReduceJSCallConstruct(Node* node); |
- Reduction ReduceJSCallConstructWithSpread(Node* node); |
+ Reduction ReduceJSConstruct(Node* node); |
+ Reduction ReduceJSConstructWithSpread(Node* node); |
Reduction ReduceJSCallFunction(Node* node); |
enum HolderLookup { kHolderNotFound, kHolderIsReceiver, kHolderFound }; |
@@ -23,7 +23,7 @@ class JSGraph; |
class JSOperatorBuilder; |
class SimplifiedOperatorBuilder; |
-// Performs strength reduction on {JSCallConstruct} and {JSCallFunction} nodes, |
+// Performs strength reduction on {JSConstruct} and {JSCallFunction} nodes, |
// which might allow inlining or other optimizations to be performed afterwards. |
class JSCallReducer final : public AdvancedReducer { |